from pycasestyle.abstract.case import Case
from pycasestyle.libs.string import clear_string, split_string


class PascalCase(Case):
    def from_string(self, value: str) -> str:
        """
        Returns the text converted to pascalcase style

            Parameters:
                    value (string): The text you need convert to pascalcase

            Returns:
                    pascalcase text (str): Text in pascalcase style

            Example:
                    print(pascalcase.from_string("I want a pascal") # => "IWantAPascal"
        """
        value = clear_string(value)
        value = value.lower()
        if value.strip() == "":
            return ""
        parts = split_string(r'[_\s]+', value)
        return ''.join(part.capitalize() for part in parts)

    def from_dict(self, __dict: dict) -> dict:
        """
        Returns the dict converted all keys to pascalcase style

            Parameters:
                    __dict (dict): The text you need convert to pascalcase

            Returns:
                    pascalcase dict (dict): Dict with keys in pascalcase style

            Example:
                    print(pascalcase.from_dict({"I want a pascal": True}) # => {"IWantAPascal": True}
        """
        pascal_case_dict = {}
        for key, value in __dict.items():
            pascal_case_key = self.from_string(key)
            if isinstance(value, dict):
                value = self.from_dict(value)
            pascal_case_dict[pascal_case_key] = value
        return pascal_case_dict



from pycasestyle.abstract.case import Case
from pycasestyle.libs.string import clear_string


class CamelCase(Case):
    def from_string(self, value: str) -> str:
        """
        Returns the text converted to camelcase style

            Parameters:
                    value (string): The text you need convert to camelcase

            Returns:
                    camelcase text (str): Text in camelcase style

            Example:
                    print(camelcase.from_string("I want a camel") # => "iWantACamel"
        """
        value = clear_string(value)
        if value.strip() == "":
            return ""
        words = value.split()
        camel_case_words = [words[0].lower()] + [word.capitalize() for word in words[1:]]
        return ''.join(camel_case_words)

    def from_dict(self, __dict: dict) -> dict:
        """
        Returns the dict converted all keys to camelcase style

            Parameters:
                    __dict (dict): The text you need convert to camelcase

            Returns:
                    camelcase dict (dict): Dict with keys in camelcase style

            Example:
                    print(camelcase.from_dict({"I want a camel": True}) # => {"iWantACamel": True}
        """
        camel_case_dict = {}
        for key, value in __dict.items():
            camel_case_key = self.from_string(key)
            if isinstance(value, dict):
                value = self.from_dict(value)
            camel_case_dict[camel_case_key] = value
        return camel_case_dict



from pycasestyle.abstract.case import Case
from pycasestyle.libs.string import clear_string, replacement


class SnakeCase(Case):
    def from_string(self, value: str) -> str:
        """
        Returns the text converted to snakecase style

            Parameters:
                    value (string): The text you need convert to snakecase

            Returns:
                    snakecase text (str): Text in snakecase style

            Example:
                    print(snakecase.from_string("I want a snake") # => "i_want_a_snake"
        """
        value = clear_string(value)
        value = value.lower()
        if value.strip() == "":
            return ""
        return replacement(r'\s+', value)

    def from_dict(self, __dict: dict) -> dict:
        """
        Returns the dict converted all keys to snakecase style

            Parameters:
                    __dict (dict): The text you need convert to snakecase

            Returns:
                    snakecase dict (dict): Dict with keys in snakecase style

            Example:
                    print(snakecase.from_dict({"I want a snake": True}) # => {"i_want_a_snake": True}
        """
        snake_case_dict = {}
        for key, value in __dict.items():
            snake_case_key = self.from_string(key)
            if isinstance(value, dict):
                value = self.from_dict(value)
            snake_case_dict[snake_case_key] = value
        return snake_case_dict



import unittest
from pycasestyle.camelcase import CamelCase


class TestCamelCase(unittest.TestCase):
    def setUp(self):
        self.camel_case_converter = CamelCase()

    def test_from_string(self):
        self.assertEqual(self.camel_case_converter.from_string("I want a camel"), "iWantACamel")

    def test_from_dict(self):
        input_dict = {"I want a camel": True, "Another String": False}
        expected_output = {"iWantACamel": True, "anotherString": False}
        self.assertEqual(self.camel_case_converter.from_dict(input_dict), expected_output)


if __name__ == '__main__':
    unittest.main()


import unittest

from pycasestyle.kebabcase import KebabCase


class TestKebabCase(unittest.TestCase):
    def setUp(self):
        self.kebab_case_instance = KebabCase()

    def test_from_string(self):
        self.assertEqual(self.kebab_case_instance.from_string("I want a camel"), "i-want-a-camel")

    def test_from_string_with_empty_string(self):
        self.assertEqual(self.kebab_case_instance.from_string(""), "")

    def test_from_string_with_special_characters(self):
        self.assertEqual(self.kebab_case_instance.from_string("!$%"), "")

    def test_from_string_with_numbers(self):
        self.assertEqual(self.kebab_case_instance.from_string("123abc"), "123abc")

    def test_from_dict(self):
        input_dict = {"I want a camel": True}
        expected_output = {"i-want-a-camel": True}
        self.assertEqual(self.kebab_case_instance.from_dict(input_dict), expected_output)

    def test_from_dict_with_empty_dict(self):
        self.assertEqual(self.kebab_case_instance.from_dict({}), {})

    def test_from_dict_with_multiple_entries(self):
        input_dict = {"I want a camel": True, "Another key": False}
        expected_output = {"i-want-a-camel": True, "another-key": False}
        self.assertEqual(self.kebab_case_instance.from_dict(input_dict), expected_output)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# coding=utf-8

from setuptools import setup

with open('README.rst', 'r', encoding='utf-8') as f:
    readme = f.read()

setup(
    name='pycasestyle',
    version='v0.1.2',
    keywords=['pycasestyle', 'camelcase', 'snakecase', 'pascal case', 'kebab case', 'dict key case', 'string case'],
    description='A simple python lib to convert string and dict keys to camelcase, pascal case, kebab case and snake case.',
    long_description=readme,
    long_description_content_type="text/markdown",
    author='Pedro Rodrigues',
    author_email='pedrota.rodrigues@gmail.com',
    url='https://github.com/preduus/pycasestyle',
    py_modules=['pycasestyle'],
    packages=['pycasestyle'],
    license='Apache License 2.0',
    zip_safe=False,
    test_suite="tests",
    python_requires='>=3',
    install_requires=['Unidecode==1.3.8'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ]
)


from pycasestyle.abstract.case import Case
from pycasestyle.libs.string import clear_string, replacement


class KebabCase(Case):
    def from_string(self, value: str) -> str:
        """
        Returns the text converted to kebabcase style

            Parameters:
                    value (string): The text you need convert to kebabcase

            Returns:
                    kebabcase text (str): Text in kebabcase style

            Example:
                    print(kebabcase.from_string("I want a kebab") # => "i-want-a-kebab"
        """
        value = clear_string(value)
        value = value.lower()
        if value.strip() == "":
            return ""
        return replacement(r'\s+', value, '-')

    def from_dict(self, __dict: dict) -> dict:
        """
        Returns the dict converted all keys to kebabcase style

            Parameters:
                    __dict (dict): The text you need convert to kebabcase

            Returns:
                    kebabcase dict (dict): Dict with keys in kebabcase style

            Example:
                    print(kebabcase.from_dict({"I want a kebab": True}) # => {"i-want-a-kebab": True}
        """
        kebab_case_dict = {}
        for key, value in __dict.items():
            kebab_case_key = self.from_string(key)
            if isinstance(value, dict):
                value = self.from_dict(value)
            kebab_case_dict[kebab_case_key] = value
        return kebab_case_dict



"""
pycasestyle.

A python case styles conversions lib.
Supported types:
    - CamelCase
    - SnakeCase
    - Kebab
    - Pascal
"""

__version__ = "1.0.0"
__author__ = 'Pedro Rodrigues'

from pycasestyle.camelcase import CamelCase as _CamelCase
from pycasestyle.snakecase import SnakeCase as _SnakeCase
from pycasestyle.kebabcase import KebabCase as _KebabCase
from pycasestyle.pascalcase import PascalCase as _PascalCase

camelcase = _CamelCase()
snakecase = _SnakeCase()
kebabcase = _KebabCase()
pascalcase = _PascalCase()

__all__ = ["camelcase", "snakecase", "kebabcase", "pascalcase"]